/*
Pluck: an open source trivia game for Android

Copyright (C) 2021 Joguitos do luca0N!

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see <https://www.gnu.org/licenses/>.

This game is a fork of LibreTrivia, and its source code is available at
<https://github.com/tryton-vanmeer/LibreTrivia>.

Contact us at <joguitos+pluck@luca0n.com>.
*/

package com.luca0n.joguitos.pluck.trivia;

import android.text.Html;

import com.google.gson.JsonObject;

public class TriviaQuestionBoolean extends TriviaQuestion {

    private final Boolean correctAnswer;

    public TriviaQuestionBoolean(TriviaCategory category, TriviaDifficulty difficulty,
                                 String question, boolean correctAnswer) {
        super(category, difficulty, question);
        this.correctAnswer = correctAnswer;
    }

    @Override
    public boolean checkAnswer(String guess) {
        return this.correctAnswer.equals(Boolean.valueOf(guess));
    }

    public boolean checkAnswer(Boolean guess) {
        return checkAnswer(guess.toString());
    }

    public static TriviaQuestionBoolean fromJson(JsonObject json) {
        TriviaCategory category = TriviaCategory.get(json.get("category").getAsString());
        TriviaDifficulty difficulty = TriviaDifficulty.get(json.get("difficulty").getAsString());
        String question = Html.fromHtml(json.get("question").getAsString()).toString();
        Boolean correctAnswer = json.get("correct_answer").getAsBoolean();

        return new TriviaQuestionBoolean(category, difficulty, question, correctAnswer);
    }
}
