/*
Pluck: an open source trivia game for Android

Copyright (C) 2021 Joguitos do luca0N!

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see <https://www.gnu.org/licenses/>.

This game is a fork of LibreTrivia, and its source code is available at
<https://github.com/tryton-vanmeer/LibreTrivia>.

Contact us at <joguitos+pluck@luca0n.com>.
*/

package com.luca0n.joguitos.pluck.util;

import com.google.gson.JsonArray;
import com.google.gson.JsonElement;
import com.google.gson.JsonObject;
import com.google.gson.JsonParser;

import java.io.BufferedInputStream;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.ArrayList;

import com.luca0n.joguitos.pluck.exceptions.NoTriviaResultsException;
import com.luca0n.joguitos.pluck.trivia.TriviaQuery;
import com.luca0n.joguitos.pluck.trivia.TriviaQuestion;
import com.luca0n.joguitos.pluck.trivia.TriviaQuestionBoolean;
import com.luca0n.joguitos.pluck.trivia.TriviaQuestionMultiple;
import com.luca0n.joguitos.pluck.trivia.TriviaType;

public class ApiUtil {

    private static String readStream(InputStream in) throws IOException {
        StringBuilder builder = new StringBuilder();
        BufferedReader reader = new BufferedReader(new InputStreamReader(in), 1000);

        for (String line = reader.readLine(); line != null; line = reader.readLine()) {
            builder.append(line);
        }

        in.close();
        return builder.toString();
    }

    private static String GET(String query) throws IOException {
        String response;

        URL url = new URL(query);
        HttpURLConnection connection = (HttpURLConnection) url.openConnection();

        try {
            InputStream in = new BufferedInputStream(connection.getInputStream());
            response = readStream(in);
        } finally {
            connection.disconnect();
        }

        return response;
    }

    public static String GET(TriviaQuery query) throws IOException {
        return GET(query.toString());
    }

    public static ArrayList<TriviaQuestion> jsonToQuestionArray(String json) throws NoTriviaResultsException {
        JsonObject jsonObject = new JsonParser().parse(json).getAsJsonObject();

        if (jsonObject.get("response_code").getAsInt() == 1) {
            throw new NoTriviaResultsException();
        }

        JsonArray jsonArray = jsonObject.getAsJsonArray("results");

        ArrayList<TriviaQuestion> questions = new ArrayList<>();

        for (JsonElement element : jsonArray) {
            JsonObject object = element.getAsJsonObject();
            TriviaType type = TriviaType.get(object.get("type").getAsString());

            if (type == TriviaType.MULTIPLE) {
                questions.add(TriviaQuestionMultiple.fromJson(object));
            } else {
                questions.add(TriviaQuestionBoolean.fromJson(object));
            }
        }

        return questions;
    }
}
